<style>
    .panel {
        margin-bottom: 20px;
        border: 1px solid transparent;
        border-radius: 4px;
        -webkit-box-shadow: 0 1px 1px rgba(0,0,0,.05);
        box-shadow: 0 1px 1px rgba(0,0,0,.05);
        padding: 23px;
        color: #333;
        background-color: #f5f5f5;
        border-color: #ddd;
        text-align: center;
        font-family: Arial, Helvetica, sans-serif;

        margin-left: 15%;
        margin-right: 15%;
    }

</style> 

<div class="panel panel-default">{{ message }}</div>